Description
a balanced panel of 545 individuals for 8 years 1980 to 1987 number of observations : 4360
observation : Individuals
country : United States
Format
A dataframe containing :
- id
- the individual index,
- year
- the year,
- age
- the age,
- exper
- the experience, computed as age - 6 - schooling,
- union
- does the wage is set by collective bargaining,
- married
- is the individual married ?
- ethn
- one of
'black', 'hisp' and 'other', - disability
- does the individual has health disability ?
- rural
- does the individual lives in a rural area ?
- region
- the region, one of
'NorthEast',
'NothernCentral', 'South' and 'other', - wage
- hourly wage in US dollars,
- sector
- one of
'agricultural', 'mining',
'construction', 'trade', 'transportation',
'finance', 'businessrepair', 'personalservice',
'entertainment', 'manufacturing',
'pro.rel.service', 'pub.admin', - occ
- one of
'proftech', 'manoffpro', 'sales',
'clerical', 'craftfor', 'operative',
'laborfarm', 'farmlabor', 'service'.
National Longitudinal Survey (Youth Sample)References
Vella F. and Verbeek M. (1998) Whose wages do unions raise ? A dynamic
model of unionism and wage rate determination for young men,
Journal of Applied Economics, 13, pp.163-183.